@@ -14,14 +14,9 @@ more_fn(const struct FileInfo * i)
 {
 	FILE *	input = stdin;
 	int	c;
-	int	tty = open("/dev/tty", 0);
 	int	lines = 0;
 	int	next_page = 0;
 	
-	if ( tty < 0 ) {
-		name_and_error("/dev/tty");
-		return 1;
-	}
 	if ( i && i->source && (input = fopen(i->source, "r")) < 0 )
 		name_and_error(i->source);
 	else {
@@ -44,7 +39,7 @@ more_fn(const struct FileInfo * i)
 					printf("--- press ENTER for more ---");
 					
 				fflush(stdout);
-				read(tty, &garbage, 1);
+				read(2, &garbage, 1);
 			}
 			putchar(c);
 			if ( c == '\n' && ++lines == 24 )
@@ -53,6 +48,5 @@ more_fn(const struct FileInfo * i)
 		if ( input != stdin )
 			fclose(input);
 	}
-	close(tty);
 	return 0;
 }
