@@ -7,5 +7,5 @@ const char	swapon_usage[] = "swapon block-device\n"
 extern int
 swapon_fn(const struct FileInfo * i)
 {
-	return swapon(i->source);
+	return swapon(i->source, 0);
 }
